@@ -41,32 +41,33 @@
 typedef struct _TrackerPropertyPriv TrackerPropertyPriv;
 
 struct _TrackerPropertyPriv {
-	gchar	      *uri;
-	gchar	      *name;
+	gchar         *uri;
+	gchar         *name;
 
 	TrackerPropertyType  data_type;
 	TrackerClass   *domain;
 	TrackerClass   *range;
-	gint	       weight;
+	gint           weight;
 	gboolean       indexed;
 	gboolean       fulltext_indexed;
 	gboolean       embedded;
 	gboolean       multiple_values;
 	gboolean       filtered;
 	gboolean       transient;
+	gboolean       is_inverse_functional_property;
 
 	GArray        *super_properties;
 };
 
 static void property_finalize     (GObject      *object);
 static void property_get_property (GObject      *object,
-				   guint         param_id,
-				   GValue       *value,
-				   GParamSpec   *pspec);
+                                   guint         param_id,
+                                   GValue       *value,
+                                   GParamSpec   *pspec);
 static void property_set_property (GObject      *object,
-				   guint         param_id,
-				   const GValue *value,
-				   GParamSpec   *pspec);
+                                   guint         param_id,
+                                   const GValue *value,
+                                   GParamSpec   *pspec);
 
 enum {
 	PROP_0,
@@ -81,7 +82,8 @@ enum {
 	PROP_EMBEDDED,
 	PROP_MULTIPLE_VALUES,
 	PROP_FILTERED,
-	PROP_TRANSIENT
+	PROP_TRANSIENT,
+	PROP_IS_INVERSE_FUNCTIONAL_PROPERTY
 };
 
 GType
@@ -149,97 +151,105 @@ tracker_property_class_init (TrackerPropertyClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->finalize	   = property_finalize;
+	object_class->finalize     = property_finalize;
 	object_class->get_property = property_get_property;
 	object_class->set_property = property_set_property;
 
 	g_object_class_install_property (object_class,
-					 PROP_URI,
-					 g_param_spec_string ("uri",
-							      "uri",
-							      "URI",
-							      NULL,
-							      G_PARAM_READWRITE));
+	                                 PROP_URI,
+	                                 g_param_spec_string ("uri",
+	                                                      "uri",
+	                                                      "URI",
+	                                                      NULL,
+	                                                      G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_NAME,
-					 g_param_spec_string ("name",
-							      "name",
-							      "Field name",
-							      NULL,
-							      G_PARAM_READABLE));
+	                                 PROP_NAME,
+	                                 g_param_spec_string ("name",
+	                                                      "name",
+	                                                      "Field name",
+	                                                      NULL,
+	                                                      G_PARAM_READABLE));
 	g_object_class_install_property (object_class,
-					 PROP_DATA_TYPE,
-					 g_param_spec_enum ("data-type",
-							    "data-type",
-							    "Field data type",
-							    tracker_property_type_get_type (),
-							    TRACKER_PROPERTY_TYPE_STRING,
-							    G_PARAM_READWRITE));
+	                                 PROP_DATA_TYPE,
+	                                 g_param_spec_enum ("data-type",
+	                                                    "data-type",
+	                                                    "Field data type",
+	                                                    tracker_property_type_get_type (),
+	                                                    TRACKER_PROPERTY_TYPE_STRING,
+	                                                    G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_DOMAIN,
-					 g_param_spec_object ("domain",
-							      "domain",
-							      "Domain of this property",
-							      TRACKER_TYPE_CLASS,
-							      G_PARAM_READWRITE));
+	                                 PROP_DOMAIN,
+	                                 g_param_spec_object ("domain",
+	                                                      "domain",
+	                                                      "Domain of this property",
+	                                                      TRACKER_TYPE_CLASS,
+	                                                      G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_RANGE,
-					 g_param_spec_object ("range",
-							      "range",
-							      "Range of this property",
-							      TRACKER_TYPE_CLASS,
-							      G_PARAM_READWRITE));
+	                                 PROP_RANGE,
+	                                 g_param_spec_object ("range",
+	                                                      "range",
+	                                                      "Range of this property",
+	                                                      TRACKER_TYPE_CLASS,
+	                                                      G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_WEIGHT,
-					 g_param_spec_int ("weight",
-							   "weight",
-							   "Boost to the score",
-							   0,
-							   G_MAXINT,
-							   1,
-							   G_PARAM_READWRITE));
+	                                 PROP_WEIGHT,
+	                                 g_param_spec_int ("weight",
+	                                                   "weight",
+	                                                   "Boost to the score",
+	                                                   0,
+	                                                   G_MAXINT,
+	                                                   1,
+	                                                   G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_INDEXED,
-					 g_param_spec_boolean ("indexed",
-							       "indexed",
-							       "Indexed",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	                                 PROP_INDEXED,
+	                                 g_param_spec_boolean ("indexed",
+	                                                       "indexed",
+	                                                       "Indexed",
+	                                                       TRUE,
+	                                                       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_FULLTEXT_INDEXED,
-					 g_param_spec_boolean ("fulltext-indexed",
-							       "fulltext-indexed",
-							       "Full-text indexed",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	                                 PROP_FULLTEXT_INDEXED,
+	                                 g_param_spec_boolean ("fulltext-indexed",
+	                                                       "fulltext-indexed",
+	                                                       "Full-text indexed",
+	                                                       TRUE,
+	                                                       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_EMBEDDED,
-					 g_param_spec_boolean ("embedded",
-							       "embedded",
-							       "Embedded",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	                                 PROP_EMBEDDED,
+	                                 g_param_spec_boolean ("embedded",
+	                                                       "embedded",
+	                                                       "Embedded",
+	                                                       TRUE,
+	                                                       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_MULTIPLE_VALUES,
-					 g_param_spec_boolean ("multiple-values",
-							       "multiple-values",
-							       "Multiple values",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	                                 PROP_MULTIPLE_VALUES,
+	                                 g_param_spec_boolean ("multiple-values",
+	                                                       "multiple-values",
+	                                                       "Multiple values",
+	                                                       TRUE,
+	                                                       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_FILTERED,
-					 g_param_spec_boolean ("filtered",
-							       "filtered",
-							       "Filtered",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	                                 PROP_FILTERED,
+	                                 g_param_spec_boolean ("filtered",
+	                                                       "filtered",
+	                                                       "Filtered",
+	                                                       TRUE,
+	                                                       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
-					 PROP_TRANSIENT,
-					 g_param_spec_boolean ("transient",
-							       "transient",
-							       "Transient",
-							       FALSE,
-							       G_PARAM_READWRITE));
+	                                 PROP_TRANSIENT,
+	                                 g_param_spec_boolean ("transient",
+	                                                       "transient",
+	                                                       "Transient",
+	                                                       FALSE,
+	                                                       G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+	                                 PROP_IS_INVERSE_FUNCTIONAL_PROPERTY,
+	                                 g_param_spec_boolean ("is-inverse-functional-property",
+	                                                       "is-inverse-functional-property",
+	                                                       "Is inverse functional property",
+	                                                       FALSE,
+	                                                       G_PARAM_READWRITE));
+
 
 	g_type_class_add_private (object_class, sizeof (TrackerPropertyPriv));
 }
@@ -269,6 +279,14 @@ property_finalize (GObject *object)
 	g_free (priv->uri);
 	g_free (priv->name);
 
+	if (priv->domain) {
+		g_object_unref (priv->domain);
+	}
+
+	if (priv->range) {
+		g_object_unref (priv->range);
+	}
+
 	g_array_free (priv->super_properties, TRUE);
 
 	(G_OBJECT_CLASS (tracker_property_parent_class)->finalize) (object);
@@ -276,9 +294,9 @@ property_finalize (GObject *object)
 
 static void
 property_get_property (GObject    *object,
-		       guint	   param_id,
-		       GValue     *value,
-		       GParamSpec *pspec)
+                       guint       param_id,
+                       GValue     *value,
+                       GParamSpec *pspec)
 {
 	TrackerPropertyPriv *priv;
 
@@ -321,6 +339,9 @@ property_get_property (GObject    *object,
 	case PROP_TRANSIENT:
 		g_value_set_boolean (value, priv->transient);
 		break;
+	case PROP_IS_INVERSE_FUNCTIONAL_PROPERTY:
+		g_value_set_boolean (value, priv->is_inverse_functional_property);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -328,55 +349,59 @@ property_get_property (GObject    *object,
 }
 
 static void
-property_set_property (GObject	    *object,
-		       guint	     param_id,
-		       const GValue *value,
-		       GParamSpec   *pspec)
+property_set_property (GObject      *object,
+                       guint         param_id,
+                       const GValue *value,
+                       GParamSpec   *pspec)
 {
 	switch (param_id) {
 	case PROP_URI:
 		tracker_property_set_uri (TRACKER_PROPERTY (object),
-				       g_value_get_string (value));
+		                          g_value_get_string (value));
 		break;
 	case PROP_DATA_TYPE:
 		tracker_property_set_data_type (TRACKER_PROPERTY (object),
-					     g_value_get_enum (value));
+		                                g_value_get_enum (value));
 		break;
 	case PROP_DOMAIN:
 		tracker_property_set_domain (TRACKER_PROPERTY (object),
-					   g_value_get_object (value));
+		                             g_value_get_object (value));
 		break;
 	case PROP_RANGE:
 		tracker_property_set_range (TRACKER_PROPERTY (object),
-					   g_value_get_object (value));
+		                            g_value_get_object (value));
 		break;
 	case PROP_WEIGHT:
 		tracker_property_set_weight (TRACKER_PROPERTY (object),
-					  g_value_get_int (value));
+		                             g_value_get_int (value));
 		break;
 	case PROP_INDEXED:
 		tracker_property_set_indexed (TRACKER_PROPERTY (object),
-					   g_value_get_boolean (value));
+		                              g_value_get_boolean (value));
 		break;
 	case PROP_FULLTEXT_INDEXED:
 		tracker_property_set_fulltext_indexed (TRACKER_PROPERTY (object),
-						    g_value_get_boolean (value));
+		                                       g_value_get_boolean (value));
 		break;
 	case PROP_EMBEDDED:
 		tracker_property_set_embedded (TRACKER_PROPERTY (object),
-					    g_value_get_boolean (value));
+		                               g_value_get_boolean (value));
 		break;
 	case PROP_MULTIPLE_VALUES:
 		tracker_property_set_multiple_values (TRACKER_PROPERTY (object),
-						   g_value_get_boolean (value));
+		                                      g_value_get_boolean (value));
 		break;
 	case PROP_FILTERED:
 		tracker_property_set_filtered (TRACKER_PROPERTY (object),
-					    g_value_get_boolean (value));
+		                               g_value_get_boolean (value));
 		break;
 	case PROP_TRANSIENT:
 		tracker_property_set_transient (TRACKER_PROPERTY (object),
-					    g_value_get_boolean (value));
+		                                g_value_get_boolean (value));
+		break;
+	case PROP_IS_INVERSE_FUNCTIONAL_PROPERTY:
+		tracker_property_set_is_inverse_functional_property (TRACKER_PROPERTY (object),
+		                                                     g_value_get_boolean (value));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -386,8 +411,8 @@ property_set_property (GObject	    *object,
 
 static gboolean
 field_int_validate (TrackerProperty *field,
-		    const gchar     *property,
-		    gint	     value)
+                    const gchar     *property,
+                    gint             value)
 {
 #ifdef G_DISABLE_CHECKS
 	GParamSpec *spec;
@@ -574,6 +599,18 @@ tracker_property_get_filtered (TrackerProperty *field)
 	return priv->filtered;
 }
 
+gboolean
+tracker_property_get_is_inverse_functional_property (TrackerProperty *property)
+{
+	TrackerPropertyPriv *priv;
+
+	g_return_val_if_fail (TRACKER_IS_PROPERTY (property), FALSE);
+
+	priv = GET_PRIV (property);
+
+	return priv->is_inverse_functional_property;
+}
+
 TrackerProperty **
 tracker_property_get_super_properties (TrackerProperty *property)
 {
@@ -588,7 +625,7 @@ tracker_property_get_super_properties (TrackerProperty *property)
 
 void
 tracker_property_set_uri (TrackerProperty *field,
-			  const gchar     *value)
+                          const gchar     *value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -631,7 +668,7 @@ tracker_property_set_uri (TrackerProperty *field,
 
 void
 tracker_property_set_transient (TrackerProperty *field,
-			        gboolean         value)
+                                gboolean         value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -647,7 +684,7 @@ tracker_property_set_transient (TrackerProperty *field,
 
 void
 tracker_property_set_data_type (TrackerProperty     *field,
-				TrackerPropertyType  value)
+                                TrackerPropertyType  value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -661,7 +698,7 @@ tracker_property_set_data_type (TrackerProperty     *field,
 
 void
 tracker_property_set_domain (TrackerProperty *field,
-			     TrackerClass    *value)
+                             TrackerClass    *value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -683,7 +720,7 @@ tracker_property_set_domain (TrackerProperty *field,
 
 void
 tracker_property_set_range (TrackerProperty *property,
-			   TrackerClass     *value)
+                            TrackerClass     *value)
 {
 	TrackerPropertyPriv *priv;
 	const gchar *range_uri;
@@ -721,7 +758,7 @@ tracker_property_set_range (TrackerProperty *property,
 
 void
 tracker_property_set_weight (TrackerProperty *field,
-			     gint	      value)
+                             gint             value)
 {
 	TrackerPropertyPriv *priv;
 	g_return_if_fail (TRACKER_IS_PROPERTY (field));
@@ -738,7 +775,7 @@ tracker_property_set_weight (TrackerProperty *field,
 
 void
 tracker_property_set_indexed (TrackerProperty *field,
-			      gboolean         value)
+                              gboolean         value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -752,7 +789,7 @@ tracker_property_set_indexed (TrackerProperty *field,
 
 void
 tracker_property_set_fulltext_indexed (TrackerProperty *field,
-				       gboolean	        value)
+                                       gboolean                 value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -766,7 +803,7 @@ tracker_property_set_fulltext_indexed (TrackerProperty *field,
 
 void
 tracker_property_set_embedded (TrackerProperty *field,
-			       gboolean	        value)
+                               gboolean                 value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -780,7 +817,7 @@ tracker_property_set_embedded (TrackerProperty *field,
 
 void
 tracker_property_set_multiple_values (TrackerProperty *field,
-				      gboolean         value)
+                                      gboolean         value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -799,7 +836,7 @@ tracker_property_set_multiple_values (TrackerProperty *field,
 
 void
 tracker_property_set_filtered (TrackerProperty *field,
-			       gboolean	        value)
+                               gboolean                 value)
 {
 	TrackerPropertyPriv *priv;
 
@@ -811,9 +848,23 @@ tracker_property_set_filtered (TrackerProperty *field,
 	g_object_notify (G_OBJECT (field), "filtered");
 }
 
+void
+tracker_property_set_is_inverse_functional_property (TrackerProperty *property,
+                                                     gboolean         value)
+{
+	TrackerPropertyPriv *priv;
+
+	g_return_if_fail (TRACKER_IS_PROPERTY (property));
+
+	priv = GET_PRIV (property);
+
+	priv->is_inverse_functional_property = value;
+	g_object_notify (G_OBJECT (property), "is-inverse-functional-property");
+}
+
 void
 tracker_property_set_super_properties (TrackerProperty  *property,
-				       TrackerProperty **value)
+                                       TrackerProperty **value)
 {
 	TrackerPropertyPriv *priv;
 	TrackerProperty **super_property;
@@ -832,7 +883,7 @@ tracker_property_set_super_properties (TrackerProperty  *property,
 
 void
 tracker_property_add_super_property (TrackerProperty *property,
-				     TrackerProperty *value)
+                                     TrackerProperty *value)
 {
 	TrackerPropertyPriv *priv;
 
