@@ -1,4 +1,5 @@
-/* Tracker Xmp - Album art helper functions
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
  * Copyright (C) 2008, Nokia
  *
  * This program is free software; you can redistribute it and/or
@@ -17,20 +18,22 @@
  * Boston, MA  02110-1301, USA.
  */
 
-#ifndef __TRACKER_ALBUMART_H__
-#define __TRACKER_ALBUMART_H__
+#ifndef __TRACKER_EXTRACT_ALBUMART_H__
+#define __TRACKER_EXTRACT_ALBUMART_H__
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-gboolean tracker_process_albumart (const unsigned char *buffer,
-                                   size_t               len,
-                                   const gchar         *artist,
-                                   const gchar         *album,
-                                   const gchar         *trackercnt_str,
-                                   const gchar         *uri);
+gboolean tracker_albumart_init     (void);
+void     tracker_albumart_shutdown (void);
+gboolean tracker_albumart_process  (const unsigned char *buffer,
+                                    size_t               len,
+                                    const gchar         *mime,
+                                    const gchar         *artist,
+                                    const gchar         *album,
+                                    const gchar         *filename);
 
 G_END_DECLS
 
-#endif /* __TRACKER_ALBUMART_H__ */
+#endif /* __TRACKER_MINER_EXTRACT_H__ */
