@@ -25,7 +25,6 @@
 #include <glib.h>
 
 #include <libtracker-common/tracker-os-dependant.h>
-#include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-utils.h>
 
@@ -55,23 +54,23 @@ typedef struct {
 	const gchar *uri;
 } ODTParseInfo;
 
-static void start_element_handler (GMarkupParseContext	*context,
-				   const gchar		*element_name,
-				   const gchar	       **attribute_names,
-				   const gchar	       **attribute_values,
-				   gpointer		 user_data,
-				   GError	       **error);
-static void end_element_handler   (GMarkupParseContext	*context,
-				   const gchar		*element_name,
-				   gpointer		 user_data,
-				   GError	       **error);
-static void text_handler	  (GMarkupParseContext	*context,
-				   const gchar		*text,
-				   gsize		 text_len,
-				   gpointer		 user_data,
-				   GError	       **error);
-static void extract_oasis	  (const gchar		*filename,
-				   TrackerSparqlBuilder		*metadata);
+static void start_element_handler (GMarkupParseContext  *context,
+                                   const gchar          *element_name,
+                                   const gchar         **attribute_names,
+                                   const gchar         **attribute_values,
+                                   gpointer              user_data,
+                                   GError              **error);
+static void end_element_handler   (GMarkupParseContext  *context,
+                                   const gchar          *element_name,
+                                   gpointer              user_data,
+                                   GError              **error);
+static void text_handler          (GMarkupParseContext  *context,
+                                   const gchar          *text,
+                                   gsize                 text_len,
+                                   gpointer              user_data,
+                                   GError              **error);
+static void extract_oasis         (const gchar          *filename,
+                                   TrackerSparqlBuilder                 *metadata);
 
 static TrackerExtractData extract_data[] = {
 	{ "application/vnd.oasis.opendocument.*", extract_oasis },
@@ -80,7 +79,7 @@ static TrackerExtractData extract_data[] = {
 
 static gchar *
 extract_content (const gchar *path,
-		 guint        n_words)
+                 guint        n_words)
 {
 	gchar *command, *output, *text;
 	GError *error = NULL;
@@ -105,10 +104,10 @@ extract_content (const gchar *path,
 
 static void
 extract_oasis (const gchar *uri,
-	       TrackerSparqlBuilder   *metadata)
+               TrackerSparqlBuilder   *metadata)
 {
-	gchar	      *argv[5];
-	gchar	      *xml;
+	gchar         *argv[5];
+	gchar         *xml;
 	gchar *filename = g_filename_from_uri (uri, NULL, NULL);
 	gchar *content;
 	TrackerFTSConfig *fts_config;
@@ -125,9 +124,13 @@ extract_oasis (const gchar *uri,
 	argv[3] = g_strdup ("meta.xml");
 	argv[4] = NULL;
 
+	tracker_sparql_builder_subject_iri (metadata, uri);
+	tracker_sparql_builder_predicate (metadata, "a");
+	tracker_sparql_builder_object (metadata, "nfo:PaginatedTextDocument");
+
 	if (tracker_spawn (argv, 10, &xml, NULL)) {
 		GMarkupParseContext *context;
-		GMarkupParser	     parser = {
+		GMarkupParser        parser = {
 			start_element_handler,
 			end_element_handler,
 			text_handler,
@@ -135,10 +138,6 @@ extract_oasis (const gchar *uri,
 			NULL
 		};
 
-		tracker_statement_list_insert (metadata, uri, 
-		                          RDF_TYPE, 
-		                          NFO_PREFIX "PaginatedTextDocument");
-
 		context = g_markup_parse_context_new (&parser, 0, &info, NULL);
 		g_markup_parse_context_parse (context, xml, -1, NULL);
 
@@ -165,11 +164,11 @@ extract_oasis (const gchar *uri,
 
 void
 start_element_handler (GMarkupParseContext  *context,
-		       const gchar	    *element_name,
-		       const gchar	   **attribute_names,
-		       const gchar	   **attribute_values,
-		       gpointer		     user_data,
-		       GError		   **error)
+                       const gchar          *element_name,
+                       const gchar         **attribute_names,
+                       const gchar         **attribute_values,
+                       gpointer                      user_data,
+                       GError              **error)
 {
 	ODTParseInfo *data = user_data;
 
@@ -198,14 +197,11 @@ start_element_handler (GMarkupParseContext  *context,
 
 		for (a = attribute_names, v = attribute_values; *a; ++a, ++v) {
 			if (strcmp (*a, "meta:word-count") == 0) {
-				tracker_statement_list_insert (metadata, uri,
-							  NFO_PREFIX "wordCount",
-							  *v);
-			}
-			else if (strcmp (*a, "meta:page-count") == 0) {
-				tracker_statement_list_insert (metadata, uri,
-							  NFO_PREFIX "pageCount",
-							  *v);
+				tracker_sparql_builder_predicate (metadata, "nfo:wordCount");
+				tracker_sparql_builder_object_unvalidated (metadata, *v);
+			} else if (strcmp (*a, "meta:page-count") == 0) {
+				tracker_sparql_builder_predicate (metadata, "nfo:pageCount");
+				tracker_sparql_builder_object_unvalidated (metadata, *v);
 			}
 		}
 
@@ -224,19 +220,19 @@ start_element_handler (GMarkupParseContext  *context,
 
 void
 end_element_handler (GMarkupParseContext  *context,
-		     const gchar	  *element_name,
-		     gpointer		   user_data,
-		     GError		 **error)
+                     const gchar          *element_name,
+                     gpointer              user_data,
+                     GError              **error)
 {
 	((ODTParseInfo*) user_data)->current = -1;
 }
 
 void
 text_handler (GMarkupParseContext  *context,
-	      const gchar	   *text,
-	      gsize		    text_len,
-	      gpointer		    user_data,
-	      GError		  **error)
+              const gchar          *text,
+              gsize                 text_len,
+              gpointer              user_data,
+              GError              **error)
 {
 	ODTParseInfo *data;
 	TrackerSparqlBuilder    *metadata;
@@ -248,46 +244,46 @@ text_handler (GMarkupParseContext  *context,
 
 	switch (data->current) {
 	case READ_TITLE:
-		tracker_statement_list_insert (metadata, uri,
-					  NIE_PREFIX "title",
-					  text);
+		tracker_sparql_builder_predicate (metadata, "nie:title");
+		tracker_sparql_builder_object_unvalidated (metadata, text);
 		break;
 	case READ_SUBJECT:
-		tracker_statement_list_insert (metadata, uri,
-					  NIE_PREFIX "subject",
-					  text);
+		tracker_sparql_builder_predicate (metadata, "nie:subject");
+		tracker_sparql_builder_object_unvalidated (metadata, text);
 		break;
 	case READ_AUTHOR:
-		tracker_statement_list_insert (metadata, ":", RDF_TYPE, NCO_PREFIX "Contact");
-		tracker_statement_list_insert (metadata, ":", NCO_PREFIX "fullname", text);
-		tracker_statement_list_insert (metadata, uri, NCO_PREFIX "creator", ":");
+		tracker_sparql_builder_predicate (metadata, "nco:publisher");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nco:Contact");
+
+		tracker_sparql_builder_predicate (metadata, "nco:fullname");
+		tracker_sparql_builder_object_unvalidated (metadata, text);
+		tracker_sparql_builder_object_blank_close (metadata);
 		break;
 	case READ_KEYWORDS: {
 		gchar *keywords = g_strdup (text);
 		char *lasts, *keyw;
-		for (keyw = strtok_r (keywords, ",; ", &lasts); keyw; 
+		for (keyw = strtok_r (keywords, ",; ", &lasts); keyw;
 		     keyw = strtok_r (NULL, ",; ", &lasts)) {
-			tracker_statement_list_insert (metadata,
-					  uri, NIE_PREFIX "keyword",
-					  (const gchar*) keyw);
+			tracker_sparql_builder_predicate (metadata, "nie:keyword");
+			tracker_sparql_builder_object_unvalidated (metadata, keyw);
 		}
 		g_free (keywords);
 	}
 		break;
 	case READ_COMMENTS:
-		tracker_statement_list_insert (metadata, uri,
-					  NIE_PREFIX "comment",
-					  text);
+		tracker_sparql_builder_predicate (metadata, "nie:comment");
+		tracker_sparql_builder_object_unvalidated (metadata, text);
 		break;
 	case READ_CREATED:
-		tracker_statement_list_insert (metadata, uri,
-					  NIE_PREFIX "contentCreated",
-					  text);
+		tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
+		tracker_sparql_builder_object_unvalidated (metadata, text);
 		break;
 	case READ_GENERATOR:
-		tracker_statement_list_insert (metadata, uri,
-					  NIE_PREFIX "generator",
-					  text);
+		tracker_sparql_builder_predicate (metadata, "nie:generator");
+		tracker_sparql_builder_object_unvalidated (metadata, text);
 		break;
 
 	default:
