@@ -18,18 +18,20 @@
  * Boston, MA  02110-1301, USA.
  */
 
+#include "config.h"
+
 #include <string.h>
 
 #include <glib.h>
 #include <gio/gio.h>
 
-#include <libtracker-db/tracker-db-manager.h>
+#include <libtracker-common/tracker-common.h>
+#include <libtracker-db/tracker-db.h>
 
 #include <libtracker-data/tracker-data-manager.h>
 #include <libtracker-data/tracker-data-query.h>
 #include <libtracker-data/tracker-data-update.h>
 #include <libtracker-data/tracker-sparql-query.h>
-#include <libtracker-common/tracker-ontology.h>
 
 typedef struct _TestInfo TestInfo;
 
@@ -40,6 +42,9 @@ struct _TestInfo {
 };
 
 const TestInfo tests[] = {
+	{ "aggregates/aggregate-1", "aggregates/data-1", FALSE },
+	{ "aggregates/aggregate-distinct-1", "aggregates/data-1", FALSE },
+	{ "aggregates/aggregate-group-1", "aggregates/data-1", FALSE },
 	{ "algebra/two-nested-opt", "algebra/two-nested-opt", FALSE },
 	{ "algebra/two-nested-opt-alt", "algebra/two-nested-opt", FALSE },
 	{ "algebra/opt-filter-3", "algebra/opt-filter-3", FALSE },
@@ -67,8 +72,9 @@ const TestInfo tests[] = {
 	{ "sort/query-sort-3", "sort/data-sort-3", FALSE },
 	{ "sort/query-sort-4", "sort/data-sort-4", FALSE },
 	{ "sort/query-sort-5", "sort/data-sort-4", FALSE }, 
+	{ "subqueries/subqueries-1", "subqueries/data-1", FALSE },
 	/* Bracket error after WHERE */
-	{ "error/query-error-1", "error/query-error-1", TRUE }, 
+	{ "error/query-error-1", "error/query-error-1", TRUE },
 	/* Unknown property */
 	{ "error/query-error-2", "error/query-error-2", TRUE },
 
@@ -106,14 +112,16 @@ test_sparql_query (gconstpointer test_data)
 	g_free (prefix);
 
 	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
-		                   data_prefix, 
-				   NULL, NULL);
+	                           data_prefix,
+	                           NULL, NULL);
 
 	/* data_path = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", NULL); */
 
 	/* load data set */
 	data_filename = g_strconcat (data_prefix, ".ttl", NULL);
+	tracker_data_begin_transaction ();
 	tracker_turtle_reader_load (data_filename, &error);
+	tracker_data_commit_transaction ();
 	g_assert (error == NULL);
 
 	query_filename = g_strconcat (test_prefix, ".rq", NULL);
@@ -234,11 +242,11 @@ main (int argc, char **argv)
 	if (!g_thread_supported ()) {
 		g_thread_init (NULL);
 	}
-	
+
 	g_test_init (&argc, &argv, NULL);
 
 	current_dir = g_get_current_dir ();
-	
+
 	g_setenv ("XDG_DATA_HOME", current_dir, TRUE);
 	g_setenv ("XDG_CACHE_HOME", current_dir, TRUE);
 	g_setenv ("TRACKER_DB_SQL_DIR", TOP_SRCDIR "/data/db/", TRUE);
@@ -249,7 +257,7 @@ main (int argc, char **argv)
 	/* add test cases */
 	for (i = 0; tests[i].test_name; i++) {
 		gchar *testpath;
-		
+
 		testpath = g_strconcat ("/libtracker-data/sparql/", tests[i].test_name, NULL);
 		g_test_add_data_func (testpath, &tests[i], test_sparql_query);
 		g_free (testpath);
